@@ -16,6 +16,7 @@ from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
+from .literals import AllowMessagesType, AppInstanceUserEndpointTypeType
 from .type_defs import (
     AppInstanceRetentionSettingsTypeDef,
     CreateAppInstanceAdminResponseTypeDef,
@@ -23,14 +24,20 @@ from .type_defs import (
     CreateAppInstanceUserResponseTypeDef,
     DescribeAppInstanceAdminResponseTypeDef,
     DescribeAppInstanceResponseTypeDef,
+    DescribeAppInstanceUserEndpointResponseTypeDef,
     DescribeAppInstanceUserResponseTypeDef,
+    EndpointAttributesTypeDef,
     GetAppInstanceRetentionSettingsResponseTypeDef,
     ListAppInstanceAdminsResponseTypeDef,
     ListAppInstancesResponseTypeDef,
+    ListAppInstanceUserEndpointsResponseTypeDef,
     ListAppInstanceUsersResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
     PutAppInstanceRetentionSettingsResponseTypeDef,
+    RegisterAppInstanceUserEndpointResponseTypeDef,
     TagTypeDef,
     UpdateAppInstanceResponseTypeDef,
+    UpdateAppInstanceUserEndpointResponseTypeDef,
     UpdateAppInstanceUserResponseTypeDef,
 )
 
@@ -59,7 +66,7 @@ class Exceptions:
 
 class ChimeSDKIdentityClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html)
     """
 
@@ -75,7 +82,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#can_paginate)
         """
 
@@ -90,7 +97,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Creates an Amazon Chime SDK messaging `AppInstance` under an AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#create_app_instance)
         """
 
@@ -100,7 +107,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Promotes an `AppInstanceUser` to an `AppInstanceAdmin`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance_admin)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance_admin)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#create_app_instance_admin)
         """
 
@@ -117,7 +124,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Creates a user under an Amazon Chime `AppInstance`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#create_app_instance_user)
         """
 
@@ -125,7 +132,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Deletes an `AppInstance` and all associated data asynchronously.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#delete_app_instance)
         """
 
@@ -133,7 +140,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Demotes an `AppInstanceAdmin` to an `AppInstanceUser`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance_admin)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance_admin)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#delete_app_instance_admin)
         """
 
@@ -141,15 +148,25 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Deletes an `AppInstanceUser` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#delete_app_instance_user)
         """
 
+    def deregister_app_instance_user_endpoint(
+        self, *, AppInstanceUserArn: str, EndpointId: str
+    ) -> None:
+        """
+        Deregisters an `AppInstanceUserEndpoint` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.deregister_app_instance_user_endpoint)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#deregister_app_instance_user_endpoint)
+        """
+
     def describe_app_instance(self, *, AppInstanceArn: str) -> DescribeAppInstanceResponseTypeDef:
         """
         Returns the full details of an `AppInstance` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#describe_app_instance)
         """
 
@@ -159,7 +176,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Returns the full details of an `AppInstanceAdmin` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_admin)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_admin)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#describe_app_instance_admin)
         """
 
@@ -169,10 +186,20 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Returns the full details of an `AppInstanceUser` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#describe_app_instance_user)
         """
 
+    def describe_app_instance_user_endpoint(
+        self, *, AppInstanceUserArn: str, EndpointId: str
+    ) -> DescribeAppInstanceUserEndpointResponseTypeDef:
+        """
+        Returns the full details of an `AppInstanceUserEndpoint` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_user_endpoint)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#describe_app_instance_user_endpoint)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -183,7 +210,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#generate_presigned_url)
         """
 
@@ -193,7 +220,7 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Gets the retention settings for an `AppInstance` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.get_app_instance_retention_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.get_app_instance_retention_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#get_app_instance_retention_settings)
         """
 
@@ -203,17 +230,28 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Returns a list of the administrators in the `AppInstance` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_admins)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_admins)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#list_app_instance_admins)
         """
 
+    def list_app_instance_user_endpoints(
+        self, *, AppInstanceUserArn: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListAppInstanceUserEndpointsResponseTypeDef:
+        """
+        Lists all the `AppInstanceUserEndpoints` created under a single
+        `AppInstanceUser` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_user_endpoints)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#list_app_instance_user_endpoints)
+        """
+
     def list_app_instance_users(
         self, *, AppInstanceArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAppInstanceUsersResponseTypeDef:
         """
         List all `AppInstanceUsers` created under a single `AppInstance` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#list_app_instance_users)
         """
 
@@ -223,10 +261,18 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Lists all Amazon Chime `AppInstance` s created under a single AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#list_app_instances)
         """
 
+    def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
+        """
+        Lists the tags applied to an Amazon Chime SDK identity resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#list_tags_for_resource)
+        """
+
     def put_app_instance_retention_settings(
         self,
         *,
@@ -236,17 +282,52 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Sets the amount of time in days that a given `AppInstance` retains data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.put_app_instance_retention_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.put_app_instance_retention_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#put_app_instance_retention_settings)
         """
 
+    def register_app_instance_user_endpoint(
+        self,
+        *,
+        AppInstanceUserArn: str,
+        Type: AppInstanceUserEndpointTypeType,
+        ResourceArn: str,
+        EndpointAttributes: "EndpointAttributesTypeDef",
+        ClientRequestToken: str,
+        Name: str = ...,
+        AllowMessages: AllowMessagesType = ...
+    ) -> RegisterAppInstanceUserEndpointResponseTypeDef:
+        """
+        Registers an endpoint under an Amazon Chime `AppInstanceUser`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.register_app_instance_user_endpoint)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#register_app_instance_user_endpoint)
+        """
+
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> None:
+        """
+        Applies the specified tags to the specified Amazon Chime SDK identity resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.tag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#tag_resource)
+        """
+
+    def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> None:
+        """
+        Removes the specified tags from the specified Amazon Chime SDK identity
+        resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.untag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#untag_resource)
+        """
+
     def update_app_instance(
         self, *, AppInstanceArn: str, Name: str, Metadata: str
     ) -> UpdateAppInstanceResponseTypeDef:
         """
         Updates `AppInstance` metadata.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.update_app_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.update_app_instance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#update_app_instance)
         """
 
@@ -256,6 +337,21 @@ class ChimeSDKIdentityClient(BaseClient):
         """
         Updates the details of an `AppInstanceUser`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.3/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.update_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.update_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#update_app_instance_user)
         """
+
+    def update_app_instance_user_endpoint(
+        self,
+        *,
+        AppInstanceUserArn: str,
+        EndpointId: str,
+        Name: str = ...,
+        AllowMessages: AllowMessagesType = ...
+    ) -> UpdateAppInstanceUserEndpointResponseTypeDef:
+        """
+        Updates the details of an `AppInstanceUserEndpoint`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.update_app_instance_user_endpoint)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client.html#update_app_instance_user_endpoint)
+        """
