@@ -15,6 +15,13 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Sequence
 
+from .literals import (
+    AllowMessagesType,
+    AppInstanceUserEndpointTypeType,
+    EndpointStatusReasonType,
+    EndpointStatusType,
+)
+
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -27,6 +34,8 @@ __all__ = (
     "AppInstanceRetentionSettingsTypeDef",
     "AppInstanceSummaryTypeDef",
     "AppInstanceTypeDef",
+    "AppInstanceUserEndpointSummaryTypeDef",
+    "AppInstanceUserEndpointTypeDef",
     "AppInstanceUserSummaryTypeDef",
     "AppInstanceUserTypeDef",
     "ChannelRetentionSettingsTypeDef",
@@ -39,27 +48,42 @@ __all__ = (
     "DeleteAppInstanceAdminRequestRequestTypeDef",
     "DeleteAppInstanceRequestRequestTypeDef",
     "DeleteAppInstanceUserRequestRequestTypeDef",
+    "DeregisterAppInstanceUserEndpointRequestRequestTypeDef",
     "DescribeAppInstanceAdminRequestRequestTypeDef",
     "DescribeAppInstanceAdminResponseTypeDef",
     "DescribeAppInstanceRequestRequestTypeDef",
     "DescribeAppInstanceResponseTypeDef",
+    "DescribeAppInstanceUserEndpointRequestRequestTypeDef",
+    "DescribeAppInstanceUserEndpointResponseTypeDef",
     "DescribeAppInstanceUserRequestRequestTypeDef",
     "DescribeAppInstanceUserResponseTypeDef",
+    "EndpointAttributesTypeDef",
+    "EndpointStateTypeDef",
     "GetAppInstanceRetentionSettingsRequestRequestTypeDef",
     "GetAppInstanceRetentionSettingsResponseTypeDef",
     "IdentityTypeDef",
     "ListAppInstanceAdminsRequestRequestTypeDef",
     "ListAppInstanceAdminsResponseTypeDef",
+    "ListAppInstanceUserEndpointsRequestRequestTypeDef",
+    "ListAppInstanceUserEndpointsResponseTypeDef",
     "ListAppInstanceUsersRequestRequestTypeDef",
     "ListAppInstanceUsersResponseTypeDef",
     "ListAppInstancesRequestRequestTypeDef",
     "ListAppInstancesResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "PutAppInstanceRetentionSettingsRequestRequestTypeDef",
     "PutAppInstanceRetentionSettingsResponseTypeDef",
+    "RegisterAppInstanceUserEndpointRequestRequestTypeDef",
+    "RegisterAppInstanceUserEndpointResponseTypeDef",
     "ResponseMetadataTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
+    "UntagResourceRequestRequestTypeDef",
     "UpdateAppInstanceRequestRequestTypeDef",
     "UpdateAppInstanceResponseTypeDef",
+    "UpdateAppInstanceUserEndpointRequestRequestTypeDef",
+    "UpdateAppInstanceUserEndpointResponseTypeDef",
     "UpdateAppInstanceUserRequestRequestTypeDef",
     "UpdateAppInstanceUserResponseTypeDef",
 )
@@ -112,6 +136,36 @@ AppInstanceTypeDef = TypedDict(
     total=False,
 )
 
+AppInstanceUserEndpointSummaryTypeDef = TypedDict(
+    "AppInstanceUserEndpointSummaryTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+        "Name": str,
+        "Type": AppInstanceUserEndpointTypeType,
+        "AllowMessages": AllowMessagesType,
+        "EndpointState": "EndpointStateTypeDef",
+    },
+    total=False,
+)
+
+AppInstanceUserEndpointTypeDef = TypedDict(
+    "AppInstanceUserEndpointTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+        "Name": str,
+        "Type": AppInstanceUserEndpointTypeType,
+        "ResourceArn": str,
+        "EndpointAttributes": "EndpointAttributesTypeDef",
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "AllowMessages": AllowMessagesType,
+        "EndpointState": "EndpointStateTypeDef",
+    },
+    total=False,
+)
+
 AppInstanceUserSummaryTypeDef = TypedDict(
     "AppInstanceUserSummaryTypeDef",
     {
@@ -246,6 +300,14 @@ DeleteAppInstanceUserRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeregisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "DeregisterAppInstanceUserEndpointRequestRequestTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+    },
+)
+
 DescribeAppInstanceAdminRequestRequestTypeDef = TypedDict(
     "DescribeAppInstanceAdminRequestRequestTypeDef",
     {
@@ -277,6 +339,22 @@ DescribeAppInstanceResponseTypeDef = TypedDict(
     },
 )
 
+DescribeAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "DescribeAppInstanceUserEndpointRequestRequestTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+    },
+)
+
+DescribeAppInstanceUserEndpointResponseTypeDef = TypedDict(
+    "DescribeAppInstanceUserEndpointResponseTypeDef",
+    {
+        "AppInstanceUserEndpoint": "AppInstanceUserEndpointTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeAppInstanceUserRequestRequestTypeDef = TypedDict(
     "DescribeAppInstanceUserRequestRequestTypeDef",
     {
@@ -292,6 +370,46 @@ DescribeAppInstanceUserResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredEndpointAttributesTypeDef = TypedDict(
+    "_RequiredEndpointAttributesTypeDef",
+    {
+        "DeviceToken": str,
+    },
+)
+_OptionalEndpointAttributesTypeDef = TypedDict(
+    "_OptionalEndpointAttributesTypeDef",
+    {
+        "VoipDeviceToken": str,
+    },
+    total=False,
+)
+
+
+class EndpointAttributesTypeDef(
+    _RequiredEndpointAttributesTypeDef, _OptionalEndpointAttributesTypeDef
+):
+    pass
+
+
+_RequiredEndpointStateTypeDef = TypedDict(
+    "_RequiredEndpointStateTypeDef",
+    {
+        "Status": EndpointStatusType,
+    },
+)
+_OptionalEndpointStateTypeDef = TypedDict(
+    "_OptionalEndpointStateTypeDef",
+    {
+        "StatusReason": EndpointStatusReasonType,
+    },
+    total=False,
+)
+
+
+class EndpointStateTypeDef(_RequiredEndpointStateTypeDef, _OptionalEndpointStateTypeDef):
+    pass
+
+
 GetAppInstanceRetentionSettingsRequestRequestTypeDef = TypedDict(
     "GetAppInstanceRetentionSettingsRequestRequestTypeDef",
     {
@@ -350,6 +468,38 @@ ListAppInstanceAdminsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListAppInstanceUserEndpointsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAppInstanceUserEndpointsRequestRequestTypeDef",
+    {
+        "AppInstanceUserArn": str,
+    },
+)
+_OptionalListAppInstanceUserEndpointsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAppInstanceUserEndpointsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAppInstanceUserEndpointsRequestRequestTypeDef(
+    _RequiredListAppInstanceUserEndpointsRequestRequestTypeDef,
+    _OptionalListAppInstanceUserEndpointsRequestRequestTypeDef,
+):
+    pass
+
+
+ListAppInstanceUserEndpointsResponseTypeDef = TypedDict(
+    "ListAppInstanceUserEndpointsResponseTypeDef",
+    {
+        "AppInstanceUserEndpoints": List["AppInstanceUserEndpointSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredListAppInstanceUsersRequestRequestTypeDef = TypedDict(
     "_RequiredListAppInstanceUsersRequestRequestTypeDef",
     {
@@ -401,6 +551,21 @@ ListAppInstancesResponseTypeDef = TypedDict(
     },
 )
 
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": List["TagTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 PutAppInstanceRetentionSettingsRequestRequestTypeDef = TypedDict(
     "PutAppInstanceRetentionSettingsRequestRequestTypeDef",
     {
@@ -418,6 +583,42 @@ PutAppInstanceRetentionSettingsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "Type": AppInstanceUserEndpointTypeType,
+        "ResourceArn": str,
+        "EndpointAttributes": "EndpointAttributesTypeDef",
+        "ClientRequestToken": str,
+    },
+)
+_OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef",
+    {
+        "Name": str,
+        "AllowMessages": AllowMessagesType,
+    },
+    total=False,
+)
+
+
+class RegisterAppInstanceUserEndpointRequestRequestTypeDef(
+    _RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef,
+    _OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef,
+):
+    pass
+
+
+RegisterAppInstanceUserEndpointResponseTypeDef = TypedDict(
+    "RegisterAppInstanceUserEndpointResponseTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -429,6 +630,14 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": Sequence["TagTypeDef"],
+    },
+)
+
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -437,6 +646,14 @@ TagTypeDef = TypedDict(
     },
 )
 
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "TagKeys": Sequence[str],
+    },
+)
+
 UpdateAppInstanceRequestRequestTypeDef = TypedDict(
     "UpdateAppInstanceRequestRequestTypeDef",
     {
@@ -454,6 +671,39 @@ UpdateAppInstanceResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateAppInstanceUserEndpointRequestRequestTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+    },
+)
+_OptionalUpdateAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateAppInstanceUserEndpointRequestRequestTypeDef",
+    {
+        "Name": str,
+        "AllowMessages": AllowMessagesType,
+    },
+    total=False,
+)
+
+
+class UpdateAppInstanceUserEndpointRequestRequestTypeDef(
+    _RequiredUpdateAppInstanceUserEndpointRequestRequestTypeDef,
+    _OptionalUpdateAppInstanceUserEndpointRequestRequestTypeDef,
+):
+    pass
+
+
+UpdateAppInstanceUserEndpointResponseTypeDef = TypedDict(
+    "UpdateAppInstanceUserEndpointResponseTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 UpdateAppInstanceUserRequestRequestTypeDef = TypedDict(
     "UpdateAppInstanceUserRequestRequestTypeDef",
     {
